const svg = d3.select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
    //data
    const xValue = d => d.year;
    const yValue = d => d.salary;
    const rValue = d => d.rate;
    const stateValue = d => d.state;

    //margins
    const margin = {top: 100, right: 200, bottom: 100, left: 100};
    const innerWidth = width - margin.left - margin.right;
    const innerHeight = height - margin.top - margin.bottom;

    //scales
    const xScale = d3.scaleTime()
        .domain([d3.min(data, xValue), d3.max(data, xValue)])
        .range([0, innerWidth]);

    const yScale = d3.scaleLinear()
        .domain([0, d3.max(data, yValue)])
        .range([innerHeight, 0]);

    const g = svg.append('g')
        .attr('transform', `translate(${margin.left},${margin.top})`);

    const yAxis = d3.axisLeft(yScale);

    g.append('g')
        .call(yAxis);

    const xAxis = d3.axisBottom(xScale);

    g.append('g').call(xAxis)
        .attr('transform', `translate(0,${innerHeight})`)
        .attr("font-size", 8);

    //lengend
    let colorScale = d3.scaleOrdinal()
        .domain(d3.map(data, function(d){return d.state;}).keys())
        .range(["purple", "blue", "green", "yellow"]);

    g.append("text")
        .attr("y", + -123 + height / 2)
        .attr("x", width - 155)
        .attr("font-family", "sans-serif")
        .attr("fill", "black")
        .text("States")
        .attr("font-size", 12);

    const stateVals = d3.map(data, function(d){return d.state;}).keys();

    for (var i = 0; i < stateVals.length; i++) {
        g.append("circle")
            .attr("cy", (i * 20) - 3 + innerHeight / 2)
            .attr("cx", width - 40*stateVals.length - 10)
            .attr("r", 5)
            .attr("fill", colorScale(i));

        g.append("text")
            .attr("y", (i * 20) + innerHeight / 2)
            .attr("x", width - 40*stateVals.length)
            .attr("font-family", "sans-serif")
            .attr("fill", "black")
            .text(stateVals[i])
            .attr("font-size", 12);
    }

    // Title Label
    g.append('text')
        .attr('class', 'title')
        .attr("font-size", 25)
        .attr('y', -50)
        .attr('x', 80)
        .text("Average Pay");

    // X Axis Label
    g.append('text')
        .attr('class', 'title')
        .attr("font-size", 25)
        .attr('y', height-150)
        .attr('x', 250)
        .text('Year');

    // Y Axis Label
    g.append('text')
        .attr('class', 'title')
        .attr("font-size", 25)
        .attr('y', -75)
        .attr('x', -300)
        .attr("transform", "rotate(-90)")
        .text('Salary ($)');

    //Create circles for the chart with tooltip
    g.selectAll('circle').data(data)
        .enter().append('circle')
        .attr('cy', d=> yScale(yValue(d)))
        .attr('cx', d=> xScale(xValue(d)))
        .attr('r', d=> rValue(d)/2.5)
        .attr("fill", d => colorScale(stateValue(d)))
        .append("title")
};

//Load Data and switch data to relevant data type
d3.csv('https://gist.githubusercontent.com/hollyjpotter/3ea7f8afaadedc41de4329c58f8325ef/raw/a59b987969854b4738adde31320c6ee315d34c87/newData.csv', function(data) {
    data.forEach(data => {
        data.rate = +data.rate;
        data.year = new Date(data.year);
        data.salary = +data.salary;
        data.state = data.state;
    });

    render(data);
});